#!/bin/bash
function pause {
	read -n1 -rsp $'Press any key to continue...\n'
}
function config_git {
	echo -n "Enter your name (git):"
	read name
	echo -n "Enter your email address (git):"
	read mail
	git config --global user.name "$name"
	git config --global user.email $mail
	git config --global gpg.program gpg2
	git config --global commit.gpgsign true
    	git config --global help.autocorrect 50
	git config --list
}
function install_rpms {
				#Keybase
	export rpm_links="https://prerelease.keybase.io/keybase_amd64.rpm"

				#Install RPMs specified above.
	sudo dnf install -y $rpm_links
}
function install_pip_packages {
	sudo pip install --upgrade pip
	sudo pip install powerline-status
}
function install_dnf_packages {
	export packages="vlc ffmpeg"						#Multimedia Stuff
	export packages="$packages pcsc-lite pinentry-gtk"			#Smartcard/Crypto
	export packages="$packages chromium"					#Browsers
	export packages="$packages nextcloud-client"				#Nextcloud Client
	export packages="$packages menulibre deluge syncthing* yubi*"		#GUI Tools
	export packages="$packages htop vim pass heimdall borgbackup"		#Command Line Tools
	export packages="$packages gimp digikam"				#Photography
	export packages="$packages xournal"					#Stylusstuff
	export packages="$packages latexila texlive-scheme-medium"		#LaTeX
	export packages="$packages zsh hack-fonts antigen"			#Shellstuff
	export packages="$packages java-1.8.0-openjdk* golang"			#SDKs
	export packages="$packages exfat-utils fuse-exfat"			#ExFAT
										#Android SDK Dependencies
	export packages="$packages compat-libstdc++-296.i686 compat-libstdc++-33.i686 compat-libstdc++-33.x86_64 ncurses-libs.i686"
	export packages="$packages libxcb-devel libXft-devel"			#Libraries
	sudo dnf install -y $packages --best --allowerasing
	sudo dnf upgrade -y
}
function install_software {
	add_repos
	install_rpms
	install_dnf_packages
	install_pip_packages
	install_other
}
function install_other {
			#Rust
	curl https://sh.rustup.rs -sSf | sh
	install_lemonbar
}
function install_lemonbar {
	cd ~/dev
	git clone https://github.com/krypt-n/bar lemonbar-xft
	cd lemonbar-xft
	make
	sudo cp lemonbar /usr/local/bin
}
function add_repos {
			#Negativo17 Fedora Multimedia
	sudo dnf config-manager --add-repo=http://negativo17.org/repos/fedora-multimedia.repo
			#Antigen
	sudo dnf config-manager --add-repo http://download.opensuse.org/repositories/shells:zsh-users:antigen/Fedora_26/shells:zsh-users:antigen.repo
			#RPM-Fusion Free
	sudo dnf install -y http://download1.rpmfusion.org/free/fedora/rpmfusion-free-release-$(rpm -E %fedora).noarch.rpm
			#RPM-Fusion Non Free
	sudo dnf install -y http://download1.rpmfusion.org/nonfree/fedora/rpmfusion-nonfree-release-$(rpm -E %fedora).noarch.rpm
			#Syncthing
	sudo dnf copr enable -y decathorpe/syncthing
			#Nextcloud Client
	sudo dnf copr enable -y tpokorra/nextcloud
			#Hack font
	sudo dnf copr enable -y heliocastro/hack-fonts
}
function setup_gpg_ssh {
	gpg2 --keyserver hkp://pool.sks-keyservers.net --recv-keys 816054803C0F5F14C462398B3D512CA0D8E8352E
    	sudo systemctl enable pcscd && sudo systemctl start pcscd
	sudo pkill -9 gpg-agent
	eval $(gpg-agent --daemon --enable-ssh-support --sh)
}
function clone_git_repos {
	cd ~
	git clone ssh://git@jcg.re:10022/jcgruenhage/.password-store.git

	mkcdir dev
	git clone ssh://git@jcg.re:10022/jcgruenhage/scripts.git
	git clone ssh://git@jcg.re:10022/jcgruenhage/prog16_17.git
	git clone ssh://git@jcg.re:10022/jcgruenhage/homepage.git
	git clone ssh://git@jcg.re:10022/jcgruenhage/config-files.git

	mkcdir gopath/src/git.jcg.re/jcgruenhage/
	git clone ssh://git@jcg.re:10022/jcgruenhage/go_helloworld.git

	cd ~/dev
	git clone ssh://git@github.com/jcgruenhage/freeotp-android.git
	git clone ssh://git@github.com/jcgruenhage/nextcloud-android.git
	git clone ssh://git@github.com/jcgruenhage/PlayMusicExporter.git
}
function mkcdir {
	mkdir -p -- "$1" &&
	cd -P -- "$1"
}
function configure {
	cd ~/dev/config-files
	cp .zshrc ~
	cp .config/i3/config ~/.config/i3
	cp .Xdefaults ~
	cp .xinitrc ~
}
# Execution:
install_software
setup_gpg_ssh
config_git
clone_git_repos
